/**
 * Projeto : Ticketstac
 * Classe: CadastroArtista
 *
 */

package artista;

/**
 * Title:        Projeto de LP3
 * Description:
 * Copyright:    Copyright (c) 2002
 * Company:
 * @author J Ricardo Catanho
 * @version 1.0
 */

/**
 * Classe CadastroArtista
 * Esta classe constroi e mantem o objeto CadastroArtista, que tem como
 * atributo um objeto da classe RepositorioArtistasArray.
 *
 * Limitaes: O artista so e cadastrado se forem fornecidos todos os seus atri
 *             butos.
 *
 * Exemplo de uso:
 * CadastroArtista cadastro1 = new CadastroArtista();
 *
 * cadastro1.artistas.inserir("Lisa","Harryson","10.000","001123454");
 *
 * @author J Ricardo Catanho
 *
 * @see Artista.repositorioArtistasArray
 * @see Artsita.artista
 *
 */
public class CadastroArtista  {


    private RepositorioArtistas  artistas;

    /**
     * Construtores da Classe CadastroComprador
     * Os construtores CadastroComprador inicializam cada instancia, assegurando
     * que cada objeto CadastroComprador inicie em estado consistente.
     * Todos os atributos sao colocados em letras maiusculas e retirados os
     * espacos sem significado.
     *
     */

     /**
     * Construtor da Classe CadastroArtista
     * Construtor vazio
     *
     */
     public CadastroArtista()  {
         artistas = new RepositorioArtistasArray();
     }// Construtor CadastroArtista

    /**
     * Construtor da Classe CadastroComprador
     *
     * @param repCompradores     objeto da classe RepositorioArtistasArray com o
     *                           nome do repositorio.
     *
     */
     public CadastroArtista(RepositorioArtistas repArtistas)  {
         artistas =  repArtistas;
     }// Construtor CadastroArtista

    /**
     * Este metodo retorna um objeto Artista.
     *
     * @return    objeto do tipo Artista
     *
     */
     public RepositorioArtistas getArtistas()  {
         return this.artistas;
     }// Metodo getArtistas

    /**
     * Este metodo adiciona um objeto Artista ao CadastroArtista
     *
     * Restricoes: objeto Artista so e adicionado ao ArrayArtista se
     * nao existir outro Artista com o mesmo nome e banda. Evita-se, assim,
     * duplicidade de informacao
     *
     * @param novoArtista    objeto Artista a ser inserido
     *
     */
     public void inserir(Artista novoArtista)  {
         artistas.inserir( novoArtista );
     }// Metodo inserir



    /**
     * Este metodo retorna um TRUE se o objeto esta no RepositorioArtistasArray
     *
     * @param Artista a
     *
     * @return resposta     booleano com o resusltado da compradacao
     *
     */
     public boolean existe(Artista a)  {
         boolean  resposta  = artistas.existe(a);

         return resposta;
     }// existeArtista



    /**
     * Este metodo retorna um objeto Artista se cujo nomeArtista e
     * igual ao String oferecido
     *
     * @param nome      String com o nome do artista no sistema
     *
     * @return     objeto do tipo Artista
     *
     */
     public Artista procurarArtistaNome(String nome)
           throws ArtistaNaoEncontradoException{
         return artistas.procurarNome(nome);
     }// Metodo procurarArtistaNome

    /**
     * Este metodo retorna a posicao de um objeto Artista no array
     * cujo nomeArtista e igual ao String oferecido
     *
     * @param nome     String com o nome do artista no sistema
     *
     * @return         inteiro com a posicao
     *
     */
     public int encontrarPosicao(String nome) {
         return artistas.encontrarPosicao(nome);
     }// Metodo encontrarPosicao



     /**
     * Este metodo um objeto Artista do RepositorioArtistasArray
     * Caso a operacao seja efetuada com sucesso, os objetos de posicoes
     * sucessivas sao relocados para posicao anterior
     *
     * @param nome     nome do artista no sistema
     *
     */
     public void remover(String nome)
      throws ArtistaNaoEncontradoException
      {
         artistas.remover(nome);
     }// Metodo remove

    /**
     * Este metodo procura por um artista a partir de seu nome. Caso encontrado
     * e retornado um objeto Artista com todos os seus atributos.
     *
     * @param nome    String com o nome do artista a ser procurado
     *
     * @return        objeto Artista com os dados do artista encontrado
     *
     */
     public Artista[] procurar(String nome)
     throws ArtistaNaoEncontradoException {
         return artistas.procurar(nome);
     }// Metodo procurar


    /**
     * Este metodo lista todos os artistas ja cadastrados
     *
     * @return    array de artistas
     *
     */
     public RepositorioArtistas listar()  {
         RepositorioArtistas retorno = new RepositorioArtistasArray();
         IteratorArtista artistaIte = artistas.getIterator();
         while (artistaIte.hasNext()){
            retorno.inserir(artistaIte.next());
         }
         return retorno;
     }// Metodo listar



    /**
     * Este metodo fornece o numero de artista cadastrados ate o momento
     *
     * @return     inteiro com o numero de artista cadastrados
     *
     */
     public int getNumeroArtistasCadastrados()  {
         return artistas.getNumeroArtistasCadastrados();
     }// Metodo getNumeroArtistasCadastrados



}//Classe CadastroArtista