/**
 * Projeto: Ticketstac
 * Classe: RepositorioArtistasArray
 *
 */

package artista;

/**
 * Title:        Projeto de LP3
 * Description:
 * Copyright:    Copyright (c) 2002
 * Company:
 * @author J Ricardo Catanho
 * @version 1.0
 *
 */

/**
 * Classe RepositorioArtistasArray
 * Essa classe constroe e mantem um array de objetos artista,
 * com tamanho limitado pelo  NUMERO_MAXIMO_ARTISTAS
 *
 * Limitacao:  nao deve haver duplicidade de objetos no array
 *
 * @author J Ricardo Catanho
 *
 * @see Artista.artista
 *
 */
public class RepositorioArtistasArray implements RepositorioArtistas{

    private Artista[] listaArtistas;
    private final int NUMERO_MAXIMO_ARTISTAS = 100;
    private static int indice;

    /**
     * Construtor da Classe RepositorioArtistasArray
     * O construtor RepositorioArtistasArray inicializa cada instancia,
     * assegurando que cada objeto RepositorioArtistasArray inicie em estado
     * consistente.
     * Todos os atributos sao colocados em letras maiusculas e retirados os
     * espacos sem significado.
     *
     */

    /**
     * Construtor da Classe Artista
     * Construtor vazio
     *
     * @param  NUMERO_MAXIMO_ARTISTAS    numero maximo de artistas cadastrados
     *
     */
     public RepositorioArtistasArray() {
         listaArtistas = new Artista[NUMERO_MAXIMO_ARTISTAS];
         indice = 0;
     }// Construtor RepositorioArtistaArray



    /**
     * Este metodo adiciona um objeto Artista ao CadastroArtista
     *
     * Restricoes: objeto Artista so e adicionado ao ArrayArtista se
     * nao existir outro Artista com o mesmo nome e banda. Evita-se, assim,
     * duplicidade de informacao
     *
     * @param a    objeto Artista a ser inserido
     *
     */
     public void inserir(Artista a)  {

         if (this.existe(a)== false){
             listaArtistas[indice] = new Artista(a);
             indice = indice + 1;
         }//if

     }// Metodo inserir

    /**
     * Este metodo retorna um TRUE se o objeto esta no RepositorioArtistasArray
     *
     * @param Artista a
     *
     * @return achou    booleano com o resusltado da compradacao
     *
     */
     public boolean existe(Artista a){
         boolean achou = false;

         if (indice == 0)  {
             achou = false;
         } else  {
             for ( int i = 0; i < indice; i++)  {
                 if (listaArtistas[i].equals(a))  {
                     achou = true;
                 }//if
             }//for
         }//else
         return achou;
     }// Metodo existe

    /**
     * Este metodo retorna um TRUE se o objeto esta no RepositorioArtistasArray
     *
     * @param nomeArtista        nome do artista no sistema
     * @param nomeEmpresario     nome do empresario do artista
     * @param artistaCache       cache do artista
     * @param artistaFone        telefone do artista para contato
     *
     * @return resposta     booleano com o resusltado da compradacao
     *
     */
     public boolean existe(String nomeArtista, String nomeEmpresario,
                           String artistaCache, String artistaFone)  {
         boolean achou = false;

         if (indice == 0)  {
             achou = false;
         } else  {
             for ( int i = 0; i < indice; i++)  {
                 if (listaArtistas[i].equals( nomeArtista.trim(),
                     nomeEmpresario.trim(),
                     artistaCache.trim(),
                     artistaFone.trim()))  {
                     achou = true;
                 }//if
             }//for
         }//else
         return achou;
     }// Metodo existe

    /**
     * Este metodo lista todos os artistas ja cadastrados
     *
     * @return retorno    array de artistas
     *
     */
     public Artista[] listarArtistas()  {
         Artista[] retorno = new Artista[100];
         int ponteiro = 0;
         int i;

         for ( i = 0; i<this.getNumeroArtistasCadastrados(); i++)  {
             if (listaArtistas[i] != null) {
                 retorno[ponteiro] = listaArtistas[i];
                 ponteiro++;
             }//if
         }//for
         return retorno;
     }// Metodo Listar

    /**
     * Metodo procurarNome
     * Este metodo retorna um objeto Artistase cujo nomeArtista e
     * igual ao String oferecido.
     *
     * @param nome     nome do artista no sistema
     *
     * @return retorno     objeto Artista com os dados do artista encontrado
     *
     */
     public Artista procurarNome(String nome)
      throws ArtistaNaoEncontradoException
     {
         Artista retorno = null;
         int i;
         for ( i = 0; i < indice; i++)  {
             if (listaArtistas[i].matchParcial( nome ))  {
                 retorno =  listaArtistas[i];
             }//if
         }//for
         if(retorno == null){
         throw new ArtistaNaoEncontradoException("Artista No Encontrado ");
         }
         else return retorno;
     }// Metodo procurarNome

    /**
     * Metodo encontrarPosicao
     * Este metodo retorna a posicao de um objeto Artista no array
     * cujo nomeArtista e
     * igual ao String oferecido
     *
     * @param nome          nome do artista no sistema
     *
     * @return retorno      inteiro com a posicao do artista no array
     *
     */
     public int encontrarPosicao(String nome)  {
         int retorno = -1;
         int i;
         for ( i = 0; i < indice ; i++)  {
             if (listaArtistas[i].matchParcial(nome))  {
                 retorno =  i;
             }//if
         }//for
         return retorno;
     }// Metodo encontrarPosicao

     public int encontrarPosicao(Artista a)  {
         int retorno = -1;
         int i;
         for ( i = 0; i < indice ; i++)  {
             if (listaArtistas[i].matchParcial( a ))  {
                 retorno =  i;
             }//if
         }//for
         return retorno;
     }// Metodo encontrarPosicao

    /**
     * Metodo remover
     * Este metodo um objeto Artista do RepositorioArtistasArray
     * Caso a operacao seja efetuada com sucesso, os objetos de posicoes
     * sucessivas sao relocados para posicao anterior
     *
     * @param nome     nome do artista no sistema
     *
     */
     public void remover(String nome)
     throws ArtistaNaoEncontradoException
      {
         int posicao = -1;
         int i;
         posicao = this.encontrarPosicao(nome);
         if (posicao >= 0)  {
             if (((posicao == 0) && (indice == 1)) ||
                  (posicao == (indice - 1)))  {
                 listaArtistas[posicao] = null;
                 indice = indice -1;
             } else  {
                 for ( i = posicao ; i < (indice - 1);i++)  {
                     listaArtistas[i] = listaArtistas [i+1];
                 }//for
                 listaArtistas[ indice ] = null;
                 indice = indice - 1;
             }//else
         }// if
         if (posicao == -1)
          throw new ArtistaNaoEncontradoException("Artista No Est Cadastrado");
     }// Metodo remove

    /**
     * Metodo remover
     * Este metodo um objeto Artista do RepositorioArtistasArray
     * Caso a operacao seja efetuada com sucesso, os objetos de posicoes
     * sucessivas sao relocados para posicao anterior
     *
     * @param nome      nome do artista no sistema
     * @param emp       nome do empresario do artista
     * @param cache     cache do artista
     * @param fone      telefone do artista para contato
     *
     */
     public void remover( String nome, String emp, String cache, String fone)
          throws ArtistaNaoEncontradoException
          {
          int posicao = -1;
         if (this.existe(nome, emp, cache, fone))  {
             int i,j;
             for ( i = 0; i < indice; i++)  {
                 if (listaArtistas[i].equals(nome, emp, cache, fone)== true)  {
                     posicao = i;
                 }//if
                 if (posicao == (indice - 1)) {
                     listaArtistas[posicao] = null;
                     indice = indice - 1;
                 } else  {
                     for ( j = posicao; j < indice - 1; j++)  {
                         listaArtistas[j].setNomeArtista(
                              listaArtistas[j+1].getNomeArtista());
                         listaArtistas[j].setNomeEmpresario(
                              listaArtistas[j+1].getNomeEmpresario());
                         listaArtistas[j].setArtistaCache(
                              listaArtistas[j+1].getArtistaCache());
                         listaArtistas[j].setArtistaFone(
                              listaArtistas[j+1].getArtistaFone());
                     }//for
                     listaArtistas[indice-1]= null;
                     indice = indice - 1;
                 }//else

             }//for

         }//if
         if (posicao == -1)
         throw new ArtistaNaoEncontradoException("Artista No Est Cadastrado");
     }// Metodo remover


     public void remover( Artista a)
     throws ArtistaNaoEncontradoException
      {
         int i,j;
         int posicao = -1;
         for ( i = 0; i < indice; i++)  {
             if (listaArtistas[i].equals( a )== true)  {
                 posicao = i;
             }//if
             if (posicao == (indice - 1)) {
                 listaArtistas[posicao] = null;
                 indice = indice - 1;
                 }
             else  {
                 for ( j = posicao; j < indice - 1; j++)  {
                      listaArtistas[j].setNomeArtista(
                      listaArtistas[j+1].getNomeArtista());
                      listaArtistas[j].setNomeEmpresario(
                      listaArtistas[j+1].getNomeEmpresario());
                      listaArtistas[j].setArtistaCache(
                      listaArtistas[j+1].getArtistaCache());
                      listaArtistas[j].setArtistaFone(
                      listaArtistas[j+1].getArtistaFone());
                     }//for
                     listaArtistas[indice-1]= null;
                     indice = indice - 1;
                 }//else
             }//for
          if (posicao == -1)
          throw new ArtistaNaoEncontradoException("Artista No Est Cadastrado");

     }// Metodo remover

    /**
     * Metodo getNumeroArtistasCadastrados
     * Este metodo fornece o numero de artista cadastrados ate o momento
     *
     * @return     inteiro com o numero de artista cadastrados
     *
     */
     public int getNumeroArtistasCadastrados(){
         return indice;
     }// Metodo getContador

    /**
     * Metodo procurar
     * Este metodo encontra todos os objeto Artista do
     * RepositorioArtistasArray
     * que contem a String nomeArtista fornecida
     *
     * @param nomeArtista                  nome do artista no sistema
     *
     * @return listaARtistasEncontrados    array de objetos Artista
     *
     */
     public Artista[] procurar(String nomeArtista)
         throws ArtistaNaoEncontradoException {
         int i;
         String nome = nomeArtista.toUpperCase().trim();
         String artistaNome;
         String nomeEmpresario;
         String artistaCache;
         String artistaFone;
         int posicao = 0;
         int totalEncontrado = 0;
         Artista[] listaArtistasEncontrados;
         for ( i = 0; i < indice; i++)  {
             if (listaArtistas[i].matchParcial(nome))  {
                 totalEncontrado++;
             }//if
         }//for
         listaArtistasEncontrados = new Artista[totalEncontrado];
         if (totalEncontrado > 0)  {
             for ( i = 0; i< totalEncontrado; i++)  {
                 listaArtistasEncontrados[ i ] = null;
             }//for
             for ( i = 0; i < indice; i++)  {
                 if (listaArtistas[i].matchParcial(nome))  {
                     artistaNome = listaArtistas[i].getNomeArtista();
                     nomeEmpresario = listaArtistas[i].getNomeEmpresario();
                     artistaCache = listaArtistas[i].getArtistaCache();
                     artistaFone = listaArtistas[i].getArtistaFone();
                     listaArtistasEncontrados[posicao] = new Artista();
                     listaArtistasEncontrados[posicao].setNomeArtista(
                          artistaNome);
                     listaArtistasEncontrados[posicao].setNomeEmpresario(
                          nomeEmpresario);
                     listaArtistasEncontrados[posicao].setArtistaCache(
                          artistaCache);
                     listaArtistasEncontrados[posicao].setArtistaFone(
                          artistaFone);
                     posicao++;
                 }//if
             }//for
         }// if
         if( listaArtistasEncontrados.length>0)
         return listaArtistasEncontrados;
         else throw new ArtistaNaoEncontradoException("Artista No Encontrado ");
     }// Metodo procurar
     public Artista[] procurar(Artista a)
         throws ArtistaNaoEncontradoException {
         int i;
         String nome = a.getNomeArtista();
         String artistaNome;
         String nomeEmpresario;
         String artistaCache;
         String artistaFone;
         int posicao = 0;
         int totalEncontrado = 0;
         Artista[] listaArtistasEncontrados;
         for ( i = 0; i < indice; i++)  {
             if (listaArtistas[i].matchParcial(nome))  {
                 totalEncontrado++;
             }//if
         }//for
         listaArtistasEncontrados = new Artista[totalEncontrado];
         if (totalEncontrado > 0)  {
             for ( i = 0; i< totalEncontrado; i++)  {
                 listaArtistasEncontrados[ i ] = null;
             }//for
             for ( i = 0; i < indice; i++)  {
                 if (listaArtistas[i].matchParcial(nome))  {
                     artistaNome = listaArtistas[i].getNomeArtista();
                     nomeEmpresario = listaArtistas[i].getNomeEmpresario();
                     artistaCache = listaArtistas[i].getArtistaCache();
                     artistaFone = listaArtistas[i].getArtistaFone();
                     listaArtistasEncontrados[posicao] = new Artista();
                     listaArtistasEncontrados[posicao].setNomeArtista(
                          artistaNome);
                     listaArtistasEncontrados[posicao].setNomeEmpresario(
                          nomeEmpresario);
                     listaArtistasEncontrados[posicao].setArtistaCache(
                          artistaCache);
                     listaArtistasEncontrados[posicao].setArtistaFone(
                          artistaFone);
                     posicao++;
                 }//if
             }//for
         }// if
         if( listaArtistasEncontrados.length>0)
         return listaArtistasEncontrados;
         else throw new ArtistaNaoEncontradoException("Artista No Encontrado ");
     }// Metodo procurar

     public IteratorArtista getIterator(){
        int i = 0 ;
        IteratorArtistaArray iterator = new IteratorArtistaArray();
        while(listaArtistas[i] != null)
            {
            iterator.add(listaArtistas[i]);
            i++;
        }//while
        return iterator;
     }//getIterator



}// Classe RepositorioArtistasArray