/**
 * Projeto :    Ticketstac
 * Classe:      CadastroComprador
 *
 */

package comprador;

/**
 * Title:           Projeto de LP3
 * Description:     Cadastro Comprador
 * Copyright:       Copyright (c) 2002
 * Company:         Grupo LP3
 * @author          Cristiane Gomes
 * @version         2.0
 */

/**
 * Classe CadastroComprador
 * Esta classe constroi e mantem o objeto CadastroComprador, que tem como
 * atributo um objeto da classe RepositorioCompradoresArray.
 *
 * Limitaes: Para o cadastro ser efetuado devem ser fornecidos todos os
 * atributos do objeto Comprador.
 *
 * Exemplo de uso:
 * CadastroComprador cadastro1 = new CadastroComprador();
 *
 * cadastro1.listaCompradores.inserir("Tiago", "3324.9878", "5.467.986 ssp-pe");
 *
 * @author Cristiane Gomes
 *
 * @see Comprador.comprador
 * @see Comprador.RepositorioCompradoresArray
 *
 */
public class CadastroComprador  {


    private  RepositorioCompradores listaCompradores;

    /**
     * Construtores da Classe CadastroComprador
     * Os construtores CadastroComprador inicializam cada instancia,
     * assegurando que cada objeto CadastroComprador inicie em estado
     * consistente. Todos os atributos sao colocados em letras maiusculas e
     * retirados os espacos sem significado.
     *
     */

    /**
     * Construtor da Classe CadastroComprador
     * Construtor vazio
     *
     */
     public CadastroComprador() {
         listaCompradores = new RepositorioCompradoresArray();
     }// Construtor vazio

    /**
     * Construtor da Classe CadastroComprador
     *
     * @param repCompradores     objeto da classe RepositorioCompradoresArray
     *                           com o nome do repositorio.
     *
     */
     public CadastroComprador(RepositorioCompradores repCompradores)  {
         listaCompradores = repCompradores;
     }// Construtor CadastroComprador

    /**
     * Metodo inserir
     * Este metodo insere um objeto Comprador em um repositorio de Compradores.
     *
     * @param c    objeto Comprador a ser inserido.
     *
     */
     public void inserir(Comprador c) {
         listaCompradores.inserir(c);
     }// Metodo inserir

    /**
     * Metodo inserir
     * Este metodo insere um objeto Comprador em um repositorio de Compradores.
     *
     * @param nome    String com o nome do comprador a ser inserido.
     * @param fone    String com o telefone do comprador a ser inserido.
     * @param id    String com a identidade do comprador a ser inserido.
     *
     */
//     public void inserir(String nome, String id, String fone)  {
//         listaCompradores.inserir(nome, fone, id);
//     }// Metodo inserir

    /**
     * Metodo remover
     * Este metodo remove um objeto Comprador do repositorio de Compradores.
     *
     * @param id    String com a identidade do comprador a ser removido.
     *
     */
     public void remover(String id) throws CompradorNaoEncontradoException {
         listaCompradores.remover(id);
     }// Metodo remover


    /**
     * Metodo existe
     * Este metodo verifica se um dado objeto Comprador j existe dentro do
     * repositorio de Compradores.
     *
     * @param id    String com a identidade do comprador a ser pesquisada a
     *              existencia.
     *
     * @return      Retorna "true" caso o comprador exista e "false" caso
     *              contrario.
     *
     */
     public boolean existe(String id)  {
         return listaCompradores.existe(id);
     }// Metodo existe



    /**
     * Metodo existe
     * Este metodo verifica se um dado objeto Comprador j existe dentro do
     * repositorio de Compradores.
     *
     * @param c    objeto Comprador a ser pesquisada a existencia.
     *
     * @return     Retorna "true" caso o comprador exista e "false" caso
     *             contrario.
     *
     */
     public boolean existe(Comprador c)  {
         return listaCompradores.existe(c);
     }// Metodo existe

    /**
     * Metodo getNumeroCompradores
     * Este metodo retorna o numero de compradores cadastrados ate o momento.
     *
     * @return    Retorna o inteiro correspondente ao numero de Compradores
     *            cadastrados.
     *
     */
     public int getNumeroCompradores()  {
         return listaCompradores.getNumeroCompradoresCadastrados();
     }// Metodo getNumeroCompradores

    /**
     * Metodo listar
     * Este metodo lista todos od compradores cadastrados ate o momento
     *
     * @return retorno     array de Compradores
     *
     */
     public RepositorioCompradores listar() {
         RepositorioCompradores retorno = new RepositorioCompradoresArray();
         IteratorComprador compradorIte = listaCompradores.getIterator();
         while (compradorIte.hasNext()) {
               retorno.inserir(compradorIte.next());
         }
         return retorno;
     }// Metodo listar

    /**
     * Metodo getInformacoesComprador
     * Este metodo retorna as informacoes cadastrais de um dado comprador ja
     * cadastrado.
     *
     * @param id    String com a identidade do comprador a serem retornadaa as
     *              informacoes.
     *
     * @return      Retorna um objeto Comprador com os atributos do comprador
     */
     public Comprador getInformacoesComprador(String id) throws CompradorNaoEncontradoException{
         return listaCompradores.procurarId(id);
     }// Metodo getInformacoesComprador

}//CadastroComprador