/**
 * Projeto : Ticketstac
 * Classe: Comprador
 *
 */

package comprador;

/**
 * Title:            Projeto de LP3
 * Description:      Classe Show - Representa um Show
 * Copyright:        Copyright (c) 2002
 * Company:          Grupo de LP3
 * @author           Cristiane Gomes
 * @version          2.0
 */

/**
 * Classe Comprador
 * Esta classe constroi e mantem o objeto Comprador, que tem como atributos
 * o nome, o telefone e o documento de identidade do comprdaor.
 *
 * Limitaes: Todo comprador deve ter todos os atributos declarados
 *
 * Exemplo de uso:
 * Comprador comprador1 = new Comprador("Tiago", "3324.9878",
 *                                      "5.467.986 ssp-pe" );
 *
 * comprador1.setFoneComprador("3425.6789");
 *
 */
public abstract class Comprador {

    private String nomeComprador;
    private String foneComprador;
    private String idComprador;
//    private double multiplicadorTarifarioComprador;

    /**
     * Construtores da Classe Comprador
     * Os construtores Comprador inicializam cada instancia,
     * assegurando que cada objeto Comprador inicie em estado consistente.
     * Todos os atributos sao colocados em letras maiusculas e retirados os espacos
     * sem significado.
     *
     */

    /**
     * Construtor da classe Comprador
     * Construtor vazio
     *
     */
     public Comprador() {
     }// Construtor vazio

    /**
     * Construtor da classe Comprador
     *
     * @param nomeComprador    nome do comprador no sistema.
     * @param foneComprador    telefone do comprador.
     * @param idComprador    identidade do comprador.
     *
     */
     public Comprador(String nome, String fone, String  id) {
        this.nomeComprador = nome.trim().toUpperCase();
        this.foneComprador = fone.trim();
        this.idComprador = id.trim();

     }//Construtor Comprador

    /**
     * Construtor da classe Comprador
     *
     * @param c    obtejo da classe Comprador contendo o nome o telefone e
     *             identidade do comprador.
     *
     */
     public Comprador(Comprador c)  {
         this.nomeComprador = c.nomeComprador;
         this.foneComprador = c.foneComprador;
         this.idComprador = c.idComprador;

     }//Construtor Comprador

    /**
     * Metodo getNomeComprador
     * Este mtodo retorna o nome de um objeto Comprador.
     *
     * @return nomeComprador    String que retorna com o nome do comprador.
     *
     */
     public String getNomeComprador()  {
         return nomeComprador;
     }// Metodo getNomeComprador

    /**
     * Metodo getFoneComprador
     * Este mtodo retorna o telefone de um objeto Comprador.
     *
     * @return foneComprador    String que retorna com o telefone do comprador.
     *
     */
     public String getFoneComprador()  {
         return foneComprador;
     }// Metodo getFoneComprador

    /**
     * Metodo getIdComprador
     * Este mtodo retorna o nmero de identidade de um objeto Comprador.
     *
     * @return idComprador    String que retorna com a identidade
     *                        do comprador.
     *
     */
     public String getIdComprador()  {
         return idComprador;
     }// Metodo getTipoComprador

    /**
     * Metodo getTipoComprador
     * Este mtodo retorna o tipo de um objeto Comprador( estudante ounormal)
     *
     * @return idComprador    String que retorna com a identidade
     *                        do comprador.
     *
     */
     public abstract double getTarifaComprador();// Metodo getTipoComprador


    /**
     * Metodo setNomeComprador
     * Este mtodo atribui uma String ao nomeComprador de um objeto Comprador.
     * A String  colocada em letras maisculas e sao retirados os espacos iniciais
     * e finais no representativos.
     *
     *
     * @param nomeComprador    String com o nome do comprador.
     *
     */
     public void setNomeComprador(String nomeComprador)  {
         this.nomeComprador = nomeComprador.toUpperCase().trim();
     }// Metodo setNomeComprador

    /**
     * Metodo setFoneComprador
     * Este mtodo atribui uma String ao foneComprador de um objeto Comprador.
     * A String  colocada em letras maisculas e sao retirados os espacos iniciais
     * e finais no representativos.
     *
     *
     * @param foneComprador    String com o telefone do comprador.
     *
     */
     public void setFoneComprador(String foneComprador)  {
         this.foneComprador = foneComprador.toUpperCase().trim();
     }// Metodo setFoneComprador


    /**
     * Metodo setIdentidadeComprador
     * Este mtodo atribui uma String a indentidadeComprador de um objeto Comprador.
     * A String  colocada em letras maisculas e sao retirados os espacos iniciais
     * e finais no representativos.
     *
     *
     * @param idComprador    String com a identidade do comprador.
     *
     */
     public void setIdComprador(String idComprador)  {
         this.idComprador = idComprador;
     }// Metodo setIdentidadeComprador

    /**
     * Metodo equals
     * Este mtodo retorna um booleano da comprao de dois objetos Comprador.
     * Utiliza-se a identidade do comprador.
     *
     * @param c    obtejo da classe Comprador contendo o nome o telefone e
     *             identidade do comprador.
     *
     * @return retorno    booleano com o resultado da comparacao.
     *
     */
     public boolean equals(Comprador c)  {
         boolean retorno = false;

         if ( this.idComprador.equalsIgnoreCase(c.getIdComprador()) )  {
             retorno = true;
         }//if
         return retorno;
     }// Metodo equals

    /**
     * Metodo equals
     * Este mtodo retorna um booleano da comprao de dois objetos Comprador.
     * Utiliza-se a identidade do comprador.
     *
     * @param nome    String com o nome do comprador.
     * @param fone    String com o telefone do comprador.
     * @param id    String com a identidade do comprador.
     *
     * @return retorno    booleano com o resultado da comparacao.
     *
     */
     public boolean equals(String nome, String fone, String id)  {
         boolean retorno = false;

         if ( this.getIdComprador().equalsIgnoreCase(id) )  {
              retorno = true;
         }//if
         return retorno;
     }// Metodo equals

    /**
     * Metodo Match
     * Este metodo retorna um booleano do match de dois objetos Comprador.
     *
     * @param c    objeto da classe Comprador a ser verificado;
     *
     * @return retorno    booleano que retorna o resultado do match.
     *
     */
     public boolean match(Comprador c)  {
        boolean retorno = false;

        if(this.getIdComprador().equalsIgnoreCase(c.getIdComprador()))  {
          retorno = true;
        }//if
        return retorno;
     }// Metodo match

}// Classe Comprador