/**
 * Projeto:    Ticketstac
 * Classe:     RepositorioCompradoresArray
 *
 */

package comprador;

/**
 * Title:        Ticketstac
 * Description:  Repositorio de Cadastro de Compradores - Implementado em Array
 * Copyright:    Copyright (c) 2002
 * Company:      Grupo de LP3
 * @author       Cristiane Gomes
 * @version      2.0
 */

/**
 * Classe RepositorioCompradoresArray
 * Essa classe constroe e mantem um array de objetos Comprador,
 * com tamanho limitado pelo NUMERO_MAXIMO.
 *
 * Limitacao: Para ser inserir no repositorio o objeto Comprador deve possuir
 * todos os seus atrubutos declarados.
 *
 * Exemplo de uso:
 *
 * RepositorioCompradoresArray minhaLista = new RepositorioCompradoresArray();
 *
 * minhaLista.inserir[0]("Tiago", "3324.9878", "5.467.986 ssp-pe" );
 *
 * @author Cristiane Gomes
 *
 * @see Comprador.comprador
 *
 */
public class RepositorioCompradoresArray
        implements RepositorioCompradores {


    private Comprador[] listaCompradores;// array de compradores
    private final int NUMERO_MAXIMO = 100; // numero maximo de compradores
    private static int indice; // numero de objetos inseridos no array

    /**
     * Construtor da Classe RepositorioCompradoresArray
     * O construtor RepositorioCompradoresArray inicializa cada instancia,
     * assegurando que cada objeto RepositorioCompradoresArray inicie em estado
     * consistente.
     * Todos os atributos sao colocados em letras maiusculas e retirados os
     * espacos sem significado.
     *
     */

    /**
     * Construtor da classe Artista
     * Construtor vazio
     *
     */
     public RepositorioCompradoresArray()  {
         listaCompradores = new Comprador[NUMERO_MAXIMO];
         indice = 0;
     }// Construtor RepositorioCompradoresArray


    /**
     * Metodo inserir
     * Este metodo insere um objeto Comprador no repositorio de Compradores.
     *
     * @param c    objeto Comprador a ser inserido.
     *
     */
     public void inserir (Comprador a){
          if (this.existe(a)== false){
             listaCompradores[indice] = a; //new Comprador (a);
             indice = indice + 1;
          }  else  {
                if (a.getIdComprador() == "")  {
                    //throw new ArgumentoInvalidoException("Preencha o campo: Identidade!");
                }  else  {
                    // throw new ArgumentoInvalidoException("Preencha o campo: Nome!");
                }
             }
     }// Metodo inserir

    /**
     * Metodo existe
     * Este metodo verifica se um dado objeto Comprador j existe dentro do
     * repositorio de Compradores.
     *
     * @param c    objeto Comprador a ser pesquisada a existencia.
     *
     * @return achou    booleano que retorna "true" caso o comprador exista e
     *                  "false" caso contrario.
     *
     */
     public boolean existe(Comprador c)  {
         boolean  achou = false;
         if (indice == 0)  {
             achou = false;
         } else  {
             for (int i = 0; i < indice; i++)  {
                  if (listaCompradores[i].equals(c))  {
                      achou = true;
                  }//if
             }//for
         }//else
         return achou;
     }// Metodo existe


    /**
     * Metodo existe
     * Este metodo verifica se um dado objeto Comprador j existe dentro do
     * repositorio de Compradores.
     *
     * @param ident     String com a identidade do comprador a ser pesquisada a
     *                  existencia.
     *
     * @return achou    booleano que retorna "true" caso o comprador exista e
     *                  "false" caso contrario.
     *
     */
     public boolean existe(String  ident)  {
         boolean  achou = false;

         if (indice == 0)  {
             achou = false;
         }  else  {
              for (int i = 0; i < indice; i++){
                  if (listaCompradores[i].getIdComprador(
                      ).equalsIgnoreCase(ident))  {
                      achou = true;
                  }//if
              }//for
         }//else
         return achou;
     }// Metodo existe

    /**
     * Metodo procurarId
     * Este metodo efetua a procura no repositorios por um dado comprador. Caso
     * o encontre retorna-se um objeto comprador com as informacoes cadstrais do
     * comprador.
     *
     * @param id          String com a identidade do comprador a ser procurado.
     *
     * @return retorno    objeto Comprador com as isformaoes do comprador
     *                    encontrado.
     *
     */
     public Comprador procurarId(String id)
        throws CompradorNaoEncontradoException{
         Comprador retorno = null;

         for (int i = 0; i < indice; i++)  {
              if (listaCompradores[i].getIdComprador().equalsIgnoreCase(id))  {
                  retorno =  listaCompradores[i];
              }//if
         }//for
         if(retorno == null){
                throw new CompradorNaoEncontradoException("Nao Encontrado Cliente");
         }
         return retorno;
     }// Metodo procurarId

    /**
     * Metodo encontrarPosicao
     * Este metodo retorna um inteiro com o valor da posicao de um determinado
     * comprador no array de Compradores (repositorio).
     *
     * @param id          String com a identidade do comprador que se deseja
     *                    saber posicao.
     *
     * @return retorno    inteiro que retorna a posicao do comprador caso ele
     *                    exista e "-1" caso contrario.
     *
     */
     public int encontrarPosicao(String id)  {
         int retorno = -1;

         for (int i = 0; i < indice ; i++)  {
              if (listaCompradores[i].getIdComprador().equalsIgnoreCase(id ))  {
                  retorno =  i;
              }//if
         }//for
         return retorno;
     }// Metodo encontrarPosicao

    /**
     * Metodo remover
     * Este metodo remove um objeto Comprador do repositorio de Compradores.
     *
     * @param id    String com a identidade do comprador a ser removido.
     *
     */
     public void remover( String id) throws CompradorNaoEncontradoException{
         int posicao = -1;

         posicao = this.encontrarPosicao(id);
         if (posicao >= 0 )  {
             if (((posicao == 0) && (indice == 1)) ||
                (posicao == (indice - 1)))  {
                 listaCompradores[ posicao ] = null;
                 indice = indice -1;
             } else  {
                 for (int i = posicao ; i < (indice - 1);i++)  {
                     listaCompradores[i] = listaCompradores [i+1];
                 }//for
                 listaCompradores[indice] = null;
                 indice = indice - 1;
             }//else
         } else {
              throw new CompradorNaoEncontradoException("Cliente no cadastrado!" +
              "\nRemoo no ralizada!");
           }
     }// Metodo remover

    /**
     * Metodo remover
     * Este metodo remove um objeto Comprador do repositorio de Compradores.
     *
     * @param nome    String co o nome do comprador a ser removido.
     * @param fone    String com o telefone do comprador a ser removido.
     * @param id      String com a identidade do comprador a ser removido.
     *
     */

    /**
     * Metodo listarCompradores
     * Este metodo lista todos od compradores cadastrados ate o momento
     *
     * @return retorno     array de Compradores
     *
     */
     public Comprador[] listarCompradores()  {
         Comprador[] retorno = new Comprador[100];
         int ponteiro = 0;

         for (int i = 0; i<this.getNumeroCompradoresCadastrados(); i++)  {
             if (listaCompradores[i] != null)  {
                 retorno[ponteiro] = listaCompradores[i];
                 ponteiro++;
             }//if
         }//for
         return retorno;
     }// Metodo listarCompradores

    /**
     * Metodo getNumeroCompradoresCadastrados
     * Este metodo retorna o numero de compradores cadastrados ate o momento.
     *
     * @return    Retorna o inteiro correspondente ao numero de Compradores
     *            cadastrados.
     *
     */
     public int getNumeroCompradoresCadastrados()  {
         return indice;
     }// Metodo getNumeroCompradoresCadastrados

    /**
     * Metodo getIterator
     *
     * @return     iterator
     *
     */
     public IteratorComprador getIterator(){
        int i = 0;
        IteratorCompradorArray iterator = new IteratorCompradorArray();

         while(listaCompradores[i] != null)
            {
            iterator.add(listaCompradores[i]);
            i++;
        }//while

        return iterator;
     }//getIterator

}// Classe RepositorioCompradoresArray