package show;

import java.util.GregorianCalendar;
import artista.Artista;
import artista.CadastroArtista;
import artista.IteratorArtista;
import artista.IteratorArtistaArray;
import artista.RepositorioArtistas;
import artista.RepositorioArtistasArray;


/**
 * Title:        Projeto de LP3
 * Description:  Repositorio de Cadastro de Show - Implementado em Lista
 * Copyright:    Copyright (c) 2002
 * Company:
 * @author
 * @version 1.0
 */



public class RepositorioShowsLista
	implements RepositorioShows {


  private Show atual;		         // Cabea (show) da lista.
  private RepositorioShowsLista proximos;         // Lista de shows.


    /**
     * Construtor da classe RepositoriShowsLista.
     * Cria uma lista de shows vazia.
     */
    public RepositorioShowsLista() {
    	this.atual = null;
    	this.proximos = null;
    }

    /**
     * Construtor da classe RepositoriShowsLista.
     * Cria uma lista a partir de um show.
     *
     * @param show
     */
    public RepositorioShowsLista( Show show ){
        if(show != null) {
    	      this.atual = show;
    	      this.proximos = new RepositorioShowsLista();
    	  }
    }


    /**
    * Retorna o show atual.
    *
    * @return      O show atual.
    */
    public Show getAtual() {
        return atual;
    }


   /**
    * Retorna o prximo elemento da lista de shows
    *
    * @return       Uma lista de shows.
    */
    public RepositorioShowsLista getProximo() {
        return proximos;
    }


    /**
     * Verifica se repositorio ta vazio.
     *
     * @return true se vazio, false se nao vazio
     */
    public boolean isEmpty () {
        return (this.atual == null);
    }

    /**
     * Insere um novo show.
     *
     * @param show      Show a ser inserido;
     */
    public void inserir( Show show ){

        if( show != null ) {
            if( this.atual != null ) {
                this.proximos.inserir(show);
            }else {
                 this.atual = show;
                 this.proximos = new RepositorioShowsLista();
            }
        }
    }


     /**
     * Remove um show.
     *
     * @param show       Show a ser removido;
     */
     public void remover(Show show)
        throws ListaVaziaException {

        RepositorioShowsLista pt = this;

        if(show != null) {
            while(pt.atual != null && !pt.atual.equals(show)) {
                pt = pt.proximos;
            }

            if(pt != null) {
                pt.atual = pt.proximos.atual;
                pt.proximos = pt.proximos.proximos;
            }
        }else{
            throw new ListaVaziaException("No existe nada a ser removido!!!");
        }
     }


    /**
     * Alterar show.
     *
     * @param show      Show a ser atualizado;
     */
    public void alterar( Show show ){

        int i;
        Show[] showmod;
        showmod = new Show[100];

        if( show != null ) {
            try{
    	      showmod = this.procurar( show );
              int total = this.procurar( show ).length;

               for(i=0;i < total;i++ ){
                   showmod[i].setNomeShow( show.getNomeShow() );
                   showmod[i].setArtista( show.getArtista() );
                   showmod[i].setNomeLocal( show.getNomeLocal() );
                   showmod[i].setData ( show.getData() );
                   showmod[i].setHora ( show.getHora() );
                   showmod[i].setNumeroCadeira ( show.getNumeroCadeira() );
                   showmod[i].setNumeroMesa ( show.getNumeroMesa() );
                   showmod[i].setNumeroEmPe ( show.getNumeroEmPe() );
                   showmod[i].setLotacaoCadeira ( show.getLotacaoCadeira() );
                   showmod[i].setLotacaoMesa ( show.getLotacaoMesa() );
                   showmod[i].setLotacaoEmPe ( show.getLotacaoEmPe() );
                }
            }catch(showNaoEncontradoException ex){}

         }
      }



    /**
     * Verifica se existe um determinado show.
     *
     * @param show       Show a ser verificado.
     * @return                Retorna "true" se existir.
     *                        Caso contrario, retorna "false".
     */
    public boolean existe(Show show){

        boolean retorno = false;
        RepositorioShowsLista pt = this;

        if( show != null ) {
            while( pt.atual != null && !pt.atual.equals( show ) ) {
                pt = pt.proximos;
            }

            if( pt.atual != null ) {
                retorno = true;
            }else {
                retorno = false;
            }
        }

        return retorno;
    }


    /**
     * Lista todos os shows "parecidos" com o parametro.
     *
     * @param show       Show a ser verificado.
     * @return                Array de shows.
     */
    public Show[] procurar(Show show)
        throws showNaoEncontradoException{
        int i = 0;
        int j;

        Show[] retornoaux,retorno;

        RepositorioShowsLista pt = this;
        retornoaux = new Show[100];


        while (pt.atual!=null) {
            if (pt.atual.match(show)) {
                retornoaux[i] = pt.atual;
                i++;
            }
         pt = pt.proximos;
         }
         if(i==0){
              throw new showNaoEncontradoException("Show no encontrado!!!");
         }else{

              retorno = new Show[i];
              for(j=0; j<i; j++) {
                   retorno[j]=retornoaux[j];
              }

          }
          return retorno;

     }


     public IteratorShow getIterator(){
        RepositorioShowsLista pt = this;
        IteratorShowLista iterator = new IteratorShowLista();


        while (pt.atual!=null) {
                iterator.add(pt.atual);
                pt = pt.proximos;
        }//while

        return iterator;
     }//getIterator




}
